function [ahor, azi, haut, hautcr] = equ2altaz_full (ad, dec, jul, longi, lati, Tc, Pmb)
% equa2local : Conversion equatoriales -> coordonnees locales
% Usage : [ahor, azi, haut] = equa2local (ad, de, jul)
% Entrees :
%    ad,dec : Coordonnées equatoriales
%    jul    : Date en jour julien temps UNIVERSEL
%    longi  : longitude du lieu (radian)
%    lati   : latitude du lieu (radian)
%    Tc     : Temperature en degres Celsius (facultatif)
%    Pmb    : Pression en millibar  (facultatif)
% Sorties : 
%    ahor   : angle horaire de l'étoile (radian)
%    azi    : azimut (radian)
%    haut   : hauteur (radian)
%    hautcr : hauteur corrigée de la refraction (radian)
if nargin < 7, Pmb = 1010; end
if nargin < 6, Tc = 283; end
if nargin < 5, error('equa2local necessite au moins 5 arguments : ad, dec, jul, longi, lati'); return; end
  ahor = rAsc2hAng(ad, jul, longi);
  [azi haut] = hour2hori(ahor, dec, lati);
% Correction réfraction
  dh_dg = refraction_dg(haut*180/pi, true, Tc, Pmb);
  hautcr = haut + dh_dg*pi/180.;   
endfunction

function ha = rAsc2hAng(alpha, JU, L)
% rAsc2hAng : Conversion ascension droite en angle horaire
% Usage : ha = rAsc2hAng(ang)
% Entrees : 
%   alpha : ascension droite de l'astre
%   JU    : jour julien de la date TU
%    L    : longitude du lieu (radian)
% Sortie : 
%    ha   : angle horaire
if nargin != 3, error('rAsc2hAng necessite 3 arguments : alpha, JU, L'); return; end
ha = jul2agst_rd(JU) + L - alpha;
endfunction

function tsg_rd = jul2agst_rd(ju)
% jul2agst_rd : Temps sideral apparent pour Greenwich, pour le jour julien ju
% Usage : tsg_rd = jul2agst_rd(ju);
% Ce temps est egalement l'ascension de Greenwich a cette date.
% Il est fourni en !!!!!!!!!!!!  RADIANS  !!!!!!!!!!!
if nargin != 1, error('jul2agst_rd necessite 1 argument : ju'); return; end
  T = (ju - 2451545)/36525;
  tsg_rd = jul2mgst_rd(ju);
  [dpsi deps] = nutationEcli_dg(T, true);
  eps = obliquity_dg(T) + deps;
  toRAD = pi/180.;
  eps *= toRAD;  
  tsg_rd += dpsi*cos(eps)*toRAD;  
endfunction

function tsg_rd = jul2mgst_rd(jj)
% jul2mgst_rd : Temps sideral moyen pour Greenwich, pour le jour julien jj (UT)
% Usage : tsg_rd = jul2mgst_rd(jj);
% Ce temps est egalement l'ascension de Greenwich a cette date.
% Il est fourni en !!!!!!!!!!!!  RADIANS  !!!!!!!!!!!
if nargin != 1, error('jul2mgst_rd necessite 1 argument : jj'); return; end
	djj = jj - 2451545;
	T = djj/36525;
	tsg_deg = 280.46061837 + 360.98564736629*djj + T*T*(0.000387933-T/38710000);
	tsg_deg = mod(tsg_deg, 360.);
	tsg_rd = tsg_deg*pi/180.;
endfunction

function [dpsi deps] = nutationEcli_dg(T, super)
% nutationEcli_dg : Calcul des corrections ecliptiques de nutation (dg)
% Usage : [dpsi deps] = nutationEcli_dg(T, super);
% Entrees (facultatives :
%	  T   : siecle julien du calcul = (JD-2451545)/36525;
%   super : vrai si grande precison demandee
% Sorties :
%	dpsi  : Variation de longitude ecliptique de l'axe des poles celeste
%   deps  : Variation d'obliquite de l'axe des poles celeste
if nargin < 2, super = false; end
if nargin < 1, error('nutationEcli_dg necessite au moins 1 argument : T, super'); return; end
torad = pi/180.;
if super 
	D  = 297.85036 + T*(445267.111480 + T*(-0.0019142 + T/189474));
	M  = 357.52772 + T*(35999.050340 + T*(-0.0001603 - T/300000));
	Mp = 134.96298 + T*(477198.867398 + T*(0.0086972 + T/56250));
	F  =  93.27191 + T*(483202.017538 + T*(-0.0036825 + T/327270));
	O  = 125.04452  +T*(-1934.136261 + T*(0.0020708  + T/450000));
	D *= torad;	M *= torad;	Mp *= torad;	F *= torad;	O *= torad;
	Lp = F + O;	L = Lp - D; 
	dpsi = -(171996+174.2*T)*sin(O)-(13187+1.6*T)*sin(2*L)-(2274+0.2*T)*sin(2*Lp)...
	+(2062+0.2*T)*sin(2*O)+(1426-3.4*T)*sin(M)+(712+0.1*T)*sin(Mp)+(-517+1.2*T)*sin(2*L+M)...
	-(386+0.4*T)*sin(Lp+F)-301*sin(2*Lp+Mp)+(217-0.5*T)*sin(2*L-M)-158*sin(Mp-2*D)...
	+(129+0.1*T)*sin(2*L-O)+123*sin(2*Lp-Mp)+63*sin(2*D);
	deps =  (92025+8.9*T)*cos(O)+(5736-3.1*T)*cos(2*L)+(977-0.5*T)*cos(2*Lp)...
	+(-895+0.5*T)*cos(2*O)+(54-0.1*T)*cos(M)-7*cos(Mp)+(224-0.6*T)*cos(2*L+M)...
	+200*cos(Lp+F)+(129-0.1*T)*cos(2*Lp+Mp)+(-95+0.3*T)*cos(2*L-M)-70*cos(2*L-O)-53*cos(2*Lp-Mp);
	fromdeg = 10000*3600;
    dpsi /= fromdeg;
	deps /= fromdeg;
else
	O = 125.04452  - 1934.136261*T;
    L = 280.4665 + 36000.7698*T;
    Lp = 218.3165 + 481267.8813*T;
    O *= torad;	L *= torad;	Lp *= torad; dL = 2.*L; dLp = 2.*Lp; dO = 2.*O;
    dpsi = -17.20*sin(O) - 1.32*sin(dL) - 0.23*sin(dLp) + 0.21*sin(dO);
    deps =   9.20*cos(O) + 0.57*cos(dL) + 0.10*cos(dLp) - 0.09*cos(dO);
    dpsi /= 3600.;
    deps /= 3600.;
endif
endfunction

function [eps_m_dg] = obliquity_dg(T)
% obliquity_dg : Calcul de l'obliquite moyenne en degres
% Usage : eps_m_dg = obliquity_dg(T);
% Entree :
%	  siecle julien du calcul : T  = (JD-2451545)/36525;
% Sorties :
%	 eps_m  : obliquite moyenne a la date T, en degres
if nargin != 1, error('obliquity_dg necessite 1 argument : T'); return; end
eps_m_dg = 23 + 26/60 + (21.448 - T*(46.8150 + T*(0.00059 - 0.001813*T)))/3600;
endfunction

function [azi haut] = hour2hori(HA, dec, lati)
% hour2hori : Conversion de coordonnnees horaires en horizontales
% Usage : [azi haut] = hour2hori(HA, dec, lati);
% Entrees : 
%   HA : angle horaire de l'etoile (radian)
%   dec : declinaison (radian)
%   lati : latitude du lieu (radian)
% Sorties :
%   Azi, haut : Coordonnees horizontales
% L'azimut est compte a partir du sud, positif vers l'ouest (sens horaire)
% !!!!!!!! Tous les angles sont en RADIANS   !!!!!!!!
if nargin != 3, error('hour2hori necessite 3 arguments : HA, dec, lati'); return; end
sh = sin(HA); ch = cos(HA);
sd = sin(dec); cd = cos(dec);
sp = sin(lati); cp = cos(lati);
azi = atan2(sh*cd, ch*sp*cd - sd*cp);
haut = asin(sp*sd + cp*cd*ch);
endfunction

function [dh] = refraction_dg(h, th2ap, T, P)
% refraction_dg : Variation de hauteur due a la refaction
% Usage : [dh] = refraction_dg(h, th2ap, T, P);
% Entrees :
%   h : hauteur theorique ou apparente en degres
% Entrees facultatives :
%   th2ap : si vrai h est theorique (cad vraie), et apparente si faux
%    T    : temperature en Celsius
%    P    : pression en millibar
% Sortie :
%    dh   : variation de hauteur
% Remarque :
%   Si th2ap est vrai, h = hTheorique ou vrai (par defaut)
%   Si th2ap est faux, h = hApparent ou observee
%   avec dh = hApparent - hTheorique dans les deux cas.
if nargin < 2, th2ap = true; endif
if nargin < 1, error('refraction_dg necessite au moins 1 argument : h, th2ap, T, P'); return; end
K = 1;
if nargin > 2, K = 283/(T+273); end
if nargin > 3, K *= P/1010; end
if th2ap
  arg = h + 10.3/(h + 5.1);
  if arg < 90
    arg *= pi/180.;  
    dh = K*(1.02/tan(arg))/60.;
  else dh = 0; end
else
  arg = h + 7.31/(h + 4.4);
  if arg < 90
    arg *= pi/180.;
    dh = K*(1./tan(arg))/60.;
  else dh = 0; end
end
endfunction