function [xyz lbr]  = moon_je2eclip(JD)
% moon_je2eclip : Coordonnees ecliptiques geocentriques de la Lune
%             dans le repere ecliptique equinoxe de la date
% Usage : [longi, lati, distTL]  = moon_je2eclip(JD);
% Entrees :
%    JD      : date du calcul en jour julien des ephemerides
% Sorties :
%    lbr = [longi lati distTL] avec :
%             longi, lati  : coordonnees ecliptiques geocentriques
%             distTL  : distance a la Terre en metres
%    xyz coordonnées cartésiennes ecliptiques
% Les angles sont en radians et les distances en metres
global Lune_argDa Lune_argMa Lune_argMla Lune_argFa Lune_sigLa Lune_sigRa
global Lune_argDb Lune_argMb Lune_argMlb Lune_argFb Lune_sigBb
  if isempty(Lune_argDa), moon_init(); endif
  toRadians = pi/180.;
  dist0 = 385000560.;
  JD -= (dist0/299792458.)/86400.;
% T : Temps dynamique en siècles juliens depuis J2000
  T = jul2juc(JD);
% Longitude ecliptique moyenne
  L = 218.3164477 + T*(481267.88123421 +...
              T*(-0.0015786 + T*(1./538841 - T/65194000.)));
  L = toRadians*mod(L,360.);
% Elongation moyenne de la lune (angle avec le soleil)
  D = 297.8501921 + T*(445267.1114034 +...
              T*(-0.0018819 + T*(1./545868 - T/113065000.)));
  D = toRadians*mod(D,360.);
% Anomalie Moyenne de la lune
  Ml = 134.9633964 + T*(477198.8675055 +...
            T*(0.0087414 + T*(1./69699 - T/14712000.)));
  Ml = toRadians*mod(Ml,360.);
% Anomalie Moyenne du soleil
  M = 357.5291092 + T*(35999.0502909 +...
             T*(-0.0001536 + T/24490000.));
  M = toRadians*mod(M,360.);
% Argument de latitude de la lune
  F = 93.272095 + T*(483202.0175233 +...
            T*(-0.0036539 + T*(-1./3526000 + T/863310000.)));
  F = toRadians*mod(F,360.);
% Coef. multiplicatif des sommes
  E = 1. - T*(0.002516 + T*0.0000074) ;
  E2 = E*E;
% Calcul des sommes des termes en L, B et R
  sigL = 0; sigR = 0; sigB = 0;
  for i = 1:60
    argLR = Lune_argDa(i)*D + Lune_argMa(i)*M +...
                     Lune_argMla(i)*Ml + Lune_argFa(i)*F;
    argB  = Lune_argDb(i)*D + Lune_argMb(i)*M +...
                     Lune_argMlb(i)*Ml + Lune_argFb(i)*F;
    vL = Lune_sigLa(i)*sin(argLR);
    vR = Lune_sigRa(i)*cos(argLR);
    vB = Lune_sigBb(i)*sin(argB);
    if (Lune_argMa(i) == 1 || Lune_argMa(i) == -1)
       vL *= E;  vR *= E; endif
    if (Lune_argMa(i) == 2 || Lune_argMa(i) == -2)
       vL *= E2; vR *= E2; endif
    if (Lune_argMb(i) == 1 || Lune_argMb(i) == -1)
       vB *= E; endif
    if (Lune_argMb(i) == 2 || Lune_argMb(i) == -2)
	   vB *= E2; endif
    sigL += vL;
    sigB += vB;
	sigR += vR;
  endfor
  A1 = 119.75 + 131.849*T; A1 = toRadians*mod(A1,360.);
  A2 = 53.09 + 479264.290*T; A2 = toRadians*mod(A2,360.);
  A3 = 313.45 + 481266.484*T; A3 = toRadians*mod(A3,360.);
  sigL += 3958.*sin(A1) + 1962.*sin(L-F) + 318.*sin(A2);
  sigB += -2235.*sin(L) + 382.*sin(A3) + 175.*sin(A1-F) +...
            175.*sin(A1+F) + 127.*sin(L-Ml) - 115.*sin(L+Ml);										 
% Longitude et latitude écliptique geocentriques
  longi = L + toRadians*sigL*1.e-6;
  lati = toRadians*sigB*1.e-6;
% Distance Terre-Lune
  distTL = dist0 + sigR;
  lbr = [longi lati distTL];
  dcb = distTL*cos(lati);
  xyz(1) = cos(longi)*dcb;
  xyz(2) = sin(longi)*dcb;
  xyz(3) = distTL*sin(lati);
endfunction