function [xyz lbr] = planet_je2eclipHbis(npla, JD, boolDate, boolCart)
% planet_je2eclipHbis : Coordonnees ecliptiques heliocentriques d'une planete
% Usage : [xyz lbr] = planet_je2eclipHbis(npla, JD, boolDate, boolCart);
% Entrees :
%    npla : numero de la planete (1 a 8)
%    JD: date du calcul jour julien des ephemerides
%    boolDate  : si vrai, calcul relatif au repere de la date,
%                sinon calcul relatif au repère J2000.
%    boolCart : si vrai calcul cartesien en premier
%                sinon calcul polaire en premier
% Sorties :
%    xyz : Coordonnees cartesiennes heliocentriques de la planete
%    lbr : [l, b, r] a savoir :
%		l : longitude ecliptique en radians
%		b : latitude ecliptique en radians
%		r : distance au Soleil en unite astronomique
% Les angles sont en radians et les distances en UA.
  global AllEOa AllEOb
% On utilise soit les element orbitaux du tableau AllEOa relatifs
% au repere ecliptique de la date, soit les élement orbitaux du tableau  
% AllEOb pour le repere ecliptique relatif a J2000. Ces deux tables sont
% generees et mises en global par le script makeAllEO.m   
   if isempty(AllEOa)
		makeAllEO; 
   end
   T = (JD - 2451545) / 36525;
   if boolDate, EOR = AllEOa{npla}; else EOR = AllEOb{npla}; end
% Calcul des 6 elements orbitaux a la date T.
   for i = 1:6
      eo(i) = EOR(i,1) + T*(EOR(i,2) + T*(EOR(i,3) + T*EOR(i,4)));
   end
   L  = mod(eo(1), 360)*pi/180;
   a      = eo(2); 
   ex     = eo(3);
   I      = eo(4)*pi/180.;
   gOmega = eo(5)*pi/180.;  
   gPI    = eo(6)*pi/180;
% Resolution iterative equation de Kepler
   M = L - gPI; % Anomalie moyenne en radians
   E = M; 
   for i=1:10 
      sE = sin(E); cE = cos(E);		
      erreurM = M - (E - ex*sE);
      if abs(erreurM) < 1.e-13, break; end
      E += erreurM/(1. - ex*cE);
   end
if boolCart %% Approche cartesienne par l'anomalie excentrique
% Position dans repere avec xP selon perihelie
   xP = a*(cE - ex);
   yP = a*sqrt(1.-ex*ex)*sE;
% Position dans repere avec xN selon noeud ascendant
   omega = gPI - gOmega;   % Longitude du perihelie
   co = cos(omega); so = sin(omega);
   xN = xP*co - yP*so;
   yN = xP*so + yP*co;
% Position dans le repere ecliptique
   cI = cos(I); sI = sin(I);   
   cgO = cos(gOmega); sgO = sin(gOmega);
   xE = xN*cgO - yN*cI*sgO;
   yE = xN*sgO + yN*cI*cgO;
   zE = yN*sI;
   xyz = [xE yE zE];
% Coordonnées ecliptiques
   rho = a*(1.-ex*cE);
   lambda = atan2(yE,xE);
   beta = asin(zE/rho);
   lbr = [lambda beta rho];
else %% Approche angulaire spherique par l'anomalie vraie
   rho = a*(1.-ex*cE); % Distance
   v = 2.*atan(sqrt((1.+ex)/(1.-ex))*sE/(1.+cE)); % Anomalie vraie
   u = gPI - gOmega + v; su = sin(u); % Argument de la planete / Noeud ascendant
   lambda = gOmega + atan2(cos(I)*su, cos(u)); % longitude ecliptique
   while lambda > pi, lambda -= 2*pi; end
   while lambda < -pi, lambda += 2*pi; end  
   sB = sin(I)*su; cB = sqrt(1.-sB*sB);
   beta = asin(sB); % lattitude
   lbr = [lambda beta rho];
   xE = rho*cos(lambda)*cB;
   yE = rho*sin(lambda)*cB;
   zE = rho*sB;
   xyz = [xE yE zE];  
end
endfunction