function [ra, de, rho] = planet_je2equa(JD, npla, verbose, combine)
% planet_je2equa : Coordonnees equatoriales apparentes d'une planete dans
% le repère équatorial terrestre de la date
% Usage : [ra, de] = planet_je2equa (JD, npla, verbose, combine)
% Entrees :
%    JD      : Date en jour julien ephemeride
%    npla    : numero planete : 1 Mercure, 2 Venus, 3 Soleil, 4 Mars, ....  
%    verbose : Impression des infos sur la planete si vrai          
%    combine : si vrai, correction aberration et temps-lumière combines,
%              sinon les corrections sont séparées (résultats idem) 
% Sorties : 
%    ra, de  : coordonnees equatoriales apparentes 
%    rho     : distance a la Terre en UA
% Remarque : Pour n = 3 on donne les coordonnees du Soleil.
  if nargin < 3, verbose = false; endif
  if nargin < 4, combine = false; endif
  T = jul2juc(JD);
  if npla == 3 
  % Cas position du Soleil  
    % Position de la Terre/Soleil
    [xyzT lbrT] = planet_je2eclipHvsop(3, JD);
    rho1 = lbrT(3);
    tau = 0.0057755183 * rho1;
	% Position quand la lumière est partie
    [xyzT lbrT] = planet_je2eclipHvsop(3, JD-tau);
	rho = lbrT(3);
	% On prend les coordonnées opposées
    if lbrT(1) < pi, lambda(1) = lbrT(1) + pi;
    else lambda(1) = lbrT(1) - pi; endif
    beta = -lbrT(2);
  else 
  % cas position planete  
    % Position Terre et Planète / Soleil
    [xyzT lbrT] = planet_je2eclipHvsop(3, JD);   
    [xyzP lbrP] = planet_je2eclipHvsop(npla, JD);
	% Position planete / Terre
    xyz =  xyzP - xyzT;
    rho1 = norm(xyz);
	tau = 0.0057755183 * rho1; 
    if combine
    % Corrections temps-lumière et aberration combinés			 
      [xyzT lbrT] = planet_je2eclipHvsop(3, JD-tau);   
      [xyzP lbrP] = planet_je2eclipHvsop(npla, JD-tau);
      xyz =  xyzP - xyzT;   
      rho = norm(xyz);
      lambda = atan2(xyz(2),xyz(1));
      beta = asin(xyz(3)/rho);   	
    else
    % Correction temp-lumière à part		
      [xyzP lbrP] = planet_je2eclipHvsop(npla, JD-tau);
      xyz =  xyzP - xyzT;
	    rho = norm(xyz);
      lambda = atan2(xyz(2),xyz(1));
      beta = asin(xyz(3)/rho);   
    % Correction aberration à part
      [dLamb, dBeta] = aberrEcli(lambda, beta, ...
          lbrT(1) + pi, eccentricity(T), earth_longiPerih_dg(T)*pi/180);  
      lambda += dLamb;
      beta += dBeta;
    endif
  % fin cas planète	
  endif			
% Correction nutation en coordonnées ecliptiques
  [dpsi_dg dobliq_dg] = nutationEcli_dg(T, true);
  lambda += dpsi_dg*pi/180.;	
% Coordonnees equatoriales vraies a la date
  obliq =  (obliquity_dg(T) +dobliq_dg)*pi/180;
  [ra de] = ecli2equa(lambda, beta, obliq);
  if verbose
    nompla = {"Mercure", "Vénus", " Soleil", "Mars", "Jupiter", "Saturne",...
	  "Uranus", "Neptune"};
    printf("Informations sur        : %s\n", nompla{npla});
	  printf("Distance                : %f UA\n", rho1);
    printf("AD et DE apparentes     : %s, %s\n",...
             rad2hms(ra), rad2dms2(de));  
  endif   
endfunction