function [ra, de] = star_je2equa (jD, star, verbose)
% star_je2equa : Coordonnees equatoriales apparentes d'une etoile dans le
% repère équatorial de la date
% Usage : [ra, de] = star_je2equa (JD, star, verbose)
% Entrees :
%    jD      : Date en jour julien ephemerides
%    star    : structure etoile              
%    verbose : Impression des infos sur l'etoile si vrai
% Sorties : 
%    ra, de  : coordonnees equatoriales apparentes 
if nargin < 3, verbose = false; endif
  r2s = 180*3600/pi;
% Temps écoulé depuis J2000 en annees et siècles juliens
  t = (jD - 2451545)/365.25; S = t/100.;
% Effet du mouvement propre entre J2000 et la date, dans J2000
  ad0 = star.ad0 + star.vA*t;
  de0 = star.de0 + star.vD*t;
% Calcul correction coordonnées équatoriales moyennes entre J2000 et la date
  [ra de] = chDateCoorEqua(ad0, de0, 2451545, jD);
% Calcul correction nutation en coordonnées écliptiques
  [dpsi_dg dobliq_dg] = nutationEcli_dg(S, true);
% Obliquité vrai à cette date
  obliq = (obliquity_dg(S) + dobliq_dg)*pi/180.;
% Calcul correction nutation en coordonnées equatoriales
  [dAlpha1_dg, dDelta1_dg] = nutationEqua(ra, de, obliq,...
                                                 dpsi_dg, dobliq_dg);
% Calcul aberration
  [dAlpha2, dDelta2] = aberrEqua(ra, de, obliq,...
        sun_longi_dg(S)*pi/180, eccentricity(S), earth_longiPerih_dg(S)*pi/180);
% Coordonnées équatoriales apparentes
  ra += dAlpha1_dg*pi/180 + dAlpha2;
  de += dDelta1_dg*pi/180 + dDelta2;  
  
  if verbose
    if !isempty(star.nom)
      printf("Nom commun français     : %s\n", star.nom); endif
      printf("Numéro cat. Brigth Star : %d\n", star.bsNumber);
      if length(star.bsName) > 0
        printf("Identifcation cat. B.S. : \"%s\"\n", star.bsName); endif
      if length(star.bayer) > 0
        printf("Désignation de Bayer    : %s\n", star.bayer); endif
      if star.flamsteed != 0
        printf("Désignation Flamsteed   : %d\n", star.flamsteed); endif
      if length(star.constel) > 0
        printf("Constellation           : %s\n", star.constel); endif
      if length(star.vStarId) > 0
        printf("Désignation étoile var. : %s\n", star.vStarId); endif
      printf("AD et DE (J2000/J2000)  : %s, %s\n",...
             rad2hms(star.ad0), rad2dms2(star.de0));
      printf("Dép./an AD, DE, total   : %6.3f\", %6.3f\", %6.3f\"\n",...
             star.vA*r2s, star.vD*r2s, star.vMod*r2s);
      printf("Magnitude               : %5.2f\n", star.mag);
      printf("AD et DE apparentes     : %s, %s\n",...
             rad2hms(ra), rad2dms2(de));  
  endif  
endfunction
