function sat = tle2sat(tle)
% tle2sat : Generation d'une structure satellite a partir d'une structure tle
% Usage ; sat = tle2sat(tle);
% La structure sat est generee. Les champs correspondent à la date des tle
% Champs constants sont les suivants :
%	name nom du satellite;
%	ju0 jour julien des elements orbitaux
%	a0  Demi grand axe (m)
%   e0  Excentricite
%   i0 Inclinaison (radians)
%   om0  Argument du perigee en radians
%   omP  d/dt(arg_perigee) en rd/s
%   gdOm0 Ascension droite du noeud ascendant en radians
%   gdOmP  d/dt(Ascension_droite) en rd/s
%	M0 Anomalie moyenne
%   Tn0  Periode mouvement moyen en rd/s
%   Tnod  Periode nodale en secondes
%   n0  Mouvement moyen en rd/s
%   nnod   Mouvement nodal (n0 + omP) en rd/s
%   n0dots2   1/2 d/dt (n0)
%   n0ddots6 1/6 d2/dt2(n0)
%   m3_HN Matrice rotation Rx(i0)
%   delta1  Coef de correction du a J2
	Terre_GM = 3.986004418e14; % Cte. gravitation de la Terre
	Terre_rT = 6378136.6;
	Terre_J2 = 0.0010826359; %Harmonique spherique J2 du potentiel Terrestre	
	Terre_r2J2 = Terre_rT*Terre_rT*Terre_J2;
	toRadians = pi/180.;
	coef1 = 2.*pi/86400.;
    coef2 = coef1/86400.;
    coef3 = coef2/86400.;
    n0 = tle.meanmo*coef1;        
    sat.e0 = tle.eccn;              % Excentricite
    sat.i0 = toRadians*tle.incl;    % Inclinaison (radians)
    sat.om0 = toRadians*tle.argper; % Argument du perigee en radians
    sat.gdOm0 = toRadians*tle.raan;	% Ascension droite du noeud ascendant en radians
    a1 = (Terre_GM/(n0*n0))^(1./3.);
    ume2 = 1.- sat.e0*sat.e0;
	sat.rume2 = sqrt(ume2);
    ci0 = cos(sat.i0);
    si0 = sin(sat.i0);
	sat.si0 = si0;
	sat.m3_HN = [1 0 0 ; 0 ci0 -si0 ; 0 si0 ci0];
	sat.a0 = a1;                    % Demi grand axe (m)
    p = sat.a0*ume2;
    rT2J2sp2 = Terre_r2J2/(p*p);
    sat.delta1 =  0.75*rT2J2sp2*sat.rume2*(3.*ci0*ci0-1.); % Coef de correction du a J2
    temp = rT2J2sp2*n0;
    sat.gdOmP = -1.5*temp*ci0;		% d/dt(Ascension_droite) en rd/s
    sat.omP = 0.75*temp*(5.*ci0*ci0-1.); % d/dt(arg_perigee) en rd/s
    sat.nnod = n0 + sat.omP;        % Mouvement nodal (n0 + omP) en rd/s
    sat.Tn0 = 2*pi/n0;              % Periode mouvement moyen en rd/s
    sat.Tnod = 2*pi/sat.nnod;       % Periode nodale en secondes
	sat.n0 = n0;                    % Mouvement moyen en rd/s
	sat.M0 = toRadians*tle.meanan;
    sat.n0dots2 = tle.drag*coef2;   % 1/2 d/dt (nO)
    sat.n0ddots6 = tle.nddot6*coef3;% 1/6 d2/dt2(n0)
    % jour julien des elements orbitaux	
	sat.ju0 = dmy2jul(1., 1., tle.year) + tle.refepoch - 1.;
	sat.name = tle.name;
	sat = sat_update(sat, sat.ju0);	
endfunction