function tle = tleDecode(nom, line1, line2, verbose)
% tleDecode : Decodage des 2 lignes d'une TLE
% Usage : tle = tleDecode(nom, line1, line2, verbose);
% Entrees :
%  nom     : nom a donner au satellite dans la structure TLE
%  line1   : premiere ligne de la TLE
%  line2   : deuxieme ligne de la TLE
%  verbose : si vrai, impression des elements decodes
% Sortie  :
%  tle     : Une structure contenant tous les elements de l'orbite
%     du statellite recuperes dans les 2 lignes.
  if length(line1) < 69 || length(line2) < 69 || ~check(line1,line2)
    tle = []; return;
  endif
  tle.name = nom;
  % premiere ligne
  tle.designator = strtrim(line1(10:17)); 
  tle.catnum = str2num(line1(3:7));
  tle.year = str2num(line1(19:20));
  if (tle.year <  56) tle.year += 2000; else tle.year += 1900; endif 
  tle.refepoch = str2double(line1(21:32));
  tle.drag = str2double(line1(34:43));  
  tempnum = 1.0e-5*str2double(line1(45:50));
  if tempnum ~= 0., tle.nddot6 = tempnum/(10.^(line1(52)-'0'));
  else tle.nddot6 = 0.; endif
  tempnum=1.0e-5*str2double(line1(54:59));
  if tempnum != 0., tle.bstar = tempnum/(10.^(line1(61)-'0'));
  else tle.bstar = 0.; endif
  tle.setnum = str2num(line1(65:68));
  % 2eme ligne
  tle.incl = str2double(line2(9:16));
  tle.raan = str2double(line2(18:25));
  tle.eccn = 1.0e-07*str2double(line2(27:33));
  tle.argper = str2double(line2(35:42));
  tle.meanan = str2double(line2(44:51));
  tle.meanmo = str2double(line2(53:63));
  tle.orbitnum = str2num(line2(64:68));
	if verbose
    printf("Nom du satellite :                %s\n", tle.name);
    printf("Catalog Number :                  %d\n", tle.catnum);
    printf("Element set :                     %d\n", tle.setnum);
    printf("Designation :                     %s\n", tle.designator);
    printf("Annee de la date des donnees :    %d\n", tle.year);
    printf("Jour dans l'annee :               %f\n", tle.refepoch);
    printf("Inclinaison orbite :              %f degres\n", tle.incl);
    printf("Ascension droite NA :             %f degres\n", tle.raan);
    printf("Excentricite :                    %g\n", tle.eccn);
    printf("Argument du perigee :             %f degres\n", tle.argper);
    printf("Anomalie moyenne a la date :      %f degres\n", tle.meanan);
    printf("Mouvement moyen :                 %f  tours/jour\n", tle.meanmo);
    printf("1/2 der1 mouv. moy :              %g  tours/jour**2\n", tle.drag);
    printf("1/6 der2 mouv. moy :              %g  tours/jour**3\n", tle.nddot6);
    printf("Trainee bstar :                   %g ??\n", tle.bstar);
    printf("Nombre de revolutions a la date : %d\n", tle.orbitnum);	
	endif  
endfunction

%% Verification du format des TLE
%% renvoi 1 si OK, sinon erreur
function x = check(line1, line2)
  val = zeros(1,256); val('0':'9')=0:9; val('-') = 1;
  sum1=0; sum2=0;
  for k = 1:68
    sum1 +=  val(line1(k));
	sum2 +=  val(line2(k));
  endfor
  x = (val(line1(69)) == mod(sum1,10)) &&  (val(line2(69)) == mod(sum2,10));
endfunction
